import java.util.ArrayList;

import javax.swing.table.AbstractTableModel;

/**
 * ServerStatus table model that holds 2 columns.
 */
public class ServerStatusModel extends AbstractTableModel
{
   private String    columnNames[] = new String[]{"Status", "Server", "Description"};
   private ArrayList tableData;

   /**
    * The constructor
    *
    * @param al
    */
   public ServerStatusModel(ArrayList al)
   {
      super();
      tableData = al;
   }

   /**
    * Retrive the row count
    * @return int
    */
   public int getRowCount()
   {
      return tableData.size();
   }

   /**
    * Retrive the column count
    * @return int
    */
   public int getColumnCount()
   {
      return columnNames.length;
   }

   /**
    * Retrieve the name of the column.
    * @param i
    * @return String
    */
   public String getColumnName(int i)
   {
      return columnNames[i];
   }

   /**
    * Retrieve an entire row
    * @param r
    * @return Object[]
    */
   public Object[] getRowData(int r)
   {
      if (r < tableData.size())
         return ((Object[]) tableData.get(r));
      else
         return null;
   }

   /**
    * Retrieve a particular cell
    * @param i
    * @param j
    * @return Object
    */
   public Object getValueAt(int i, int j)
   {
      if (i > tableData.size())
         return null;
      if (j > columnNames.length)
         return null;

      Object[] rowCells =  (Object[])tableData.get(i);

      return  rowCells[j];
   }

   /**
    * Set the value of a particular cell.
    * @param i
    * @param j
    * @param cell
    */
   public void setValueAt(int i, int j, Object cell)
   {
      if (i > tableData.size())
         return;
      if (j > columnNames.length)
         return;

      Object[] rowCells =  (Object[])tableData.get(i);
      rowCells[j] = cell;

      fireTableDataChanged();
   }

   /**
    * Replace table data
    * @param al
    */
   public void setTableData(ArrayList al)
   {
      this.tableData = al;

      fireTableDataChanged();
   }
}
